# PySDL3

[![Logo](logo.png)](https://github.com/Aermoss/PySDL3)

[![Deploy](https://github.com/Aermoss/PySDL3/actions/workflows/python-publish.yml/badge.svg)](https://github.com/Aermoss/PySDL3/actions/workflows/python-publish.yml)
[![PyPI Versions](https://img.shields.io/pypi/pyversions/PySDL3)](https://pypi.org/project/PySDL3)
[![PyPI](https://img.shields.io/pypi/v/PySDL3.svg)](https://pypi.org/project/PySDL3)

PySDL3 is a pure Python wrapper around the SDL3, SDL3\_mixer, SDL3\_image, SDL3\_net, SDL3\_ttf, and SDL3\_rtf libraries.

## Getting Started
Just run one of the following commands in a terminal:
```
# To install the latest stable version from PyPI:
pip install --upgrade PySDL3

# To install the latest development version from GitHub:
pip install --upgrade git+https://github.com/Aermoss/PySDL3.git
```

## Requirements
Pre-built binaries are provided within the module so there are no additional requirements.

## Documentation
There is no documentation available for now, but the function definitions are exactly the same as the SDL3 function definitions, so you can use the documentation of SDL3.